summaryrefslogtreecommitdiff
path: root/sc/source/ui/dbgui/scendlg.cxx
diff options
context:
space:
mode:
authorRüdiger Timm <rt@openoffice.org>2007-04-26 08:51:16 +0000
committerRüdiger Timm <rt@openoffice.org>2007-04-26 08:51:16 +0000
commite3fac1da27619a0528c5ad0ba8bd64a167ffdb55 (patch)
tree351eba33659d17c2be564c2526de620f2cc5e8cf /sc/source/ui/dbgui/scendlg.cxx
parente297aacca3ab88e86f7861500c8dad3307571614 (diff)
INTEGRATION: CWS residcleanup (1.13.180); FILE MERGED
2007/03/21 12:05:11 pl 1.13.180.3: #i75635# ResId cleanup 2007/03/20 17:18:08 pl 1.13.180.2: RESYNC: (1.13-1.14); FILE MERGED 2007/02/28 22:46:32 pl 1.13.180.1: #i74635# no more ResMgr fallback
Diffstat (limited to 'sc/source/ui/dbgui/scendlg.cxx')
-rw-r--r--sc/source/ui/dbgui/scendlg.cxx28
1 files changed, 14 insertions, 14 deletions
diff --git a/sc/source/ui/dbgui/scendlg.cxx b/sc/source/ui/dbgui/scendlg.cxx
index 40f1207f046a..3beffb9d6d75 100644
--- a/sc/source/ui/dbgui/scendlg.cxx
+++ b/sc/source/ui/dbgui/scendlg.cxx
@@ -4,9 +4,9 @@
*
* $RCSfile: scendlg.cxx,v $
*
- * $Revision: 1.14 $
+ * $Revision: 1.15 $
*
- * last change: $Author: vg $ $Date: 2007-02-27 13:04:37 $
+ * last change: $Author: rt $ $Date: 2007-04-26 09:51:16 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -65,19 +65,19 @@
ScNewScenarioDlg::ScNewScenarioDlg( Window* pParent, const String& rName, BOOL bEdit, BOOL bSheetProtected)
: ModalDialog ( pParent, ScResId( RID_SCDLG_NEWSCENARIO ) ),
- aFlName ( this, ResId( FL_NAME )),
+ aFlName ( this, ScResId( FL_NAME )),
aEdName ( this, ScResId( ED_NAME ) ),
- aFlComment ( this, ResId( FL_COMMENT ) ),
+ aFlComment ( this, ScResId( FL_COMMENT ) ),
aEdComment ( this, ScResId( ED_COMMENT ) ),
- aFlOptions ( this, ResId( FL_OPTIONS ) ),
- aCbShowFrame ( this, ResId( CB_SHOWFRAME ) ),
- aLbColor ( this, ResId( LB_COLOR ) ),
- //aCbPrintFrame ( this, ResId( CB_PRINTFRAME ) ),
- aCbTwoWay ( this, ResId( CB_TWOWAY ) ),
- //aCbAttrib ( this, ResId( CB_ATTRIB ) ),
- //aCbValue ( this, ResId( CB_VALUE ) ),
- aCbCopyAll ( this, ResId( CB_COPYALL ) ),
- aCbProtect ( this, ResId( CB_PROTECT ) ),
+ aFlOptions ( this, ScResId( FL_OPTIONS ) ),
+ aCbShowFrame ( this, ScResId( CB_SHOWFRAME ) ),
+ aLbColor ( this, ScResId( LB_COLOR ) ),
+ //aCbPrintFrame ( this, ScResId( CB_PRINTFRAME ) ),
+ aCbTwoWay ( this, ScResId( CB_TWOWAY ) ),
+ //aCbAttrib ( this, ScResId( CB_ATTRIB ) ),
+ //aCbValue ( this, ScResId( CB_VALUE ) ),
+ aCbCopyAll ( this, ScResId( CB_COPYALL ) ),
+ aCbProtect ( this, ScResId( CB_PROTECT ) ),
aBtnOk ( this, ScResId( BTN_OK ) ),
aBtnCancel ( this, ScResId( BTN_CANCEL ) ),
aBtnHelp ( this, ScResId( BTN_HELP ) ),
@@ -85,7 +85,7 @@ ScNewScenarioDlg::ScNewScenarioDlg( Window* pParent, const String& rName, BOOL b
bIsEdit ( bEdit )
{
if (bIsEdit)
- SetText(String(ResId(STR_EDIT)));
+ SetText(String(ScResId(STR_EDIT)));
SfxObjectShell* pDocSh = SfxObjectShell::Current();
if ( pDocSh )